# -*- coding: utf-8 -*-


"""
Module Engine

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    ExtrudeQuadsAndGenerateHexas

    ExtrudeSurface

    GenerateCylinder

    ProximityROI

    ScaleTransformMatrixEngine

    MergeMeshes

    MergeROIs

    GenerateSphere

    RigidToQuatEngine

    TransformPosition

    MeshClosingEngine

    DisplacementTransformEngine

    MeshSubsetEngine

    ComputeWeightEngine

    TextureInterpolation

    AverageCoord

    TopologyGaussPointSampler

    RandomPointDistributionInSurface

    NormalsFromPoints

    MeshBarycentricMapperEngine

    ComplementaryROI

    MergeSets

    ValuesFromIndices

    DilateEngine

    ValuesFromPositions

    ContractionInitialization

    SphereROI

    SumEngine

    MeshROI

    ExtrudeEdgesAndGenerateQuads

    Vertex2Frame

    TranslateTransformMatrixEngine

    ROIValueMapper

    IndicesFromValues

    GenerateGrid

    PairBoxROI

    TransformEngine

    DifferenceEngine

    ShapeMatching

    DisplacementMatrixEngine

    MeshSampler

    Indices2ValuesMapper

    MergeVectors

    QuatToRigidEngine

    GaussPointSmoother

    GenerateRigidMass

    MeshSplittingEngine

    MapIndices

    PlaneROI

    NormEngine

    SubsetTopology

    Spiral

    MathOp

    ProjectiveTransformEngine

    SelectConnectedLabelsROI

    MeshBoundaryROI

    ClusteringEngine

    PointsFromIndices

    IndexValueMapper

    ComputeDualQuatEngine

    HausdorffDistance

    BoxROI

    GaussPointContainer

    MergePoints

    NearestPointROI

    PythonScriptDataEngine

    RotateTransformMatrixEngine

    SelectLabelROI

    SmoothMeshEngine

    JoinPoints

    InvertTransformMatrixEngine

    GenerateCardiacCylinder

    GroupFilterYoungModulus



Content:
========

.. automodule::

    ExtrudeQuadsAndGenerateHexas

    ExtrudeSurface

    GenerateCylinder

    ProximityROI

    ScaleTransformMatrixEngine

    MergeMeshes

    MergeROIs

    GenerateSphere

    RigidToQuatEngine

    TransformPosition

    MeshClosingEngine

    DisplacementTransformEngine

    MeshSubsetEngine

    ComputeWeightEngine

    TextureInterpolation

    AverageCoord

    TopologyGaussPointSampler

    RandomPointDistributionInSurface

    NormalsFromPoints

    MeshBarycentricMapperEngine

    ComplementaryROI

    MergeSets

    ValuesFromIndices

    DilateEngine

    ValuesFromPositions

    ContractionInitialization

    SphereROI

    SumEngine

    MeshROI

    ExtrudeEdgesAndGenerateQuads

    Vertex2Frame

    TranslateTransformMatrixEngine

    ROIValueMapper

    IndicesFromValues

    GenerateGrid

    PairBoxROI

    TransformEngine

    DifferenceEngine

    ShapeMatching

    DisplacementMatrixEngine

    MeshSampler

    Indices2ValuesMapper

    MergeVectors

    QuatToRigidEngine

    GaussPointSmoother

    GenerateRigidMass

    MeshSplittingEngine

    MapIndices

    PlaneROI

    NormEngine

    SubsetTopology

    Spiral

    MathOp

    ProjectiveTransformEngine

    SelectConnectedLabelsROI

    MeshBoundaryROI

    ClusteringEngine

    PointsFromIndices

    IndexValueMapper

    ComputeDualQuatEngine

    HausdorffDistance

    BoxROI

    GaussPointContainer

    MergePoints

    NearestPointROI

    PythonScriptDataEngine

    RotateTransformMatrixEngine

    SelectLabelROI

    SmoothMeshEngine

    JoinPoints

    InvertTransformMatrixEngine

    GenerateCardiacCylinder

    GroupFilterYoungModulus



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['ExtrudeQuadsAndGenerateHexas', 'ExtrudeSurface', 'GenerateCylinder', 'ProximityROI', 'ScaleTransformMatrixEngine', 'MergeMeshes', 'MergeROIs', 'GenerateSphere', 'RigidToQuatEngine', 'TransformPosition', 'MeshClosingEngine', 'DisplacementTransformEngine', 'MeshSubsetEngine', 'ComputeWeightEngine', 'TextureInterpolation', 'AverageCoord', 'TopologyGaussPointSampler', 'RandomPointDistributionInSurface', 'NormalsFromPoints', 'MeshBarycentricMapperEngine', 'ComplementaryROI', 'MergeSets', 'ValuesFromIndices', 'DilateEngine', 'ValuesFromPositions', 'ContractionInitialization', 'SphereROI', 'SumEngine', 'MeshROI', 'ExtrudeEdgesAndGenerateQuads', 'Vertex2Frame', 'TranslateTransformMatrixEngine', 'ROIValueMapper', 'IndicesFromValues', 'GenerateGrid', 'PairBoxROI', 'TransformEngine', 'DifferenceEngine', 'ShapeMatching', 'DisplacementMatrixEngine', 'MeshSampler', 'Indices2ValuesMapper', 'MergeVectors', 'QuatToRigidEngine', 'GaussPointSmoother', 'GenerateRigidMass', 'MeshSplittingEngine', 'MapIndices', 'PlaneROI', 'NormEngine', 'SubsetTopology', 'Spiral', 'MathOp', 'ProjectiveTransformEngine', 'SelectConnectedLabelsROI', 'MeshBoundaryROI', 'ClusteringEngine', 'PointsFromIndices', 'IndexValueMapper', 'ComputeDualQuatEngine', 'HausdorffDistance', 'BoxROI', 'GaussPointContainer', 'MergePoints', 'NearestPointROI', 'PythonScriptDataEngine', 'RotateTransformMatrixEngine', 'SelectLabelROI', 'SmoothMeshEngine', 'JoinPoints', 'InvertTransformMatrixEngine', 'GenerateCardiacCylinder', 'GroupFilterYoungModulus']
class Engine:
    from .ExtrudeQuadsAndGenerateHexas import ExtrudeQuadsAndGenerateHexas
    from .ExtrudeSurface import ExtrudeSurface
    from .GenerateCylinder import GenerateCylinder
    from .ProximityROI import ProximityROI
    from .ScaleTransformMatrixEngine import ScaleTransformMatrixEngine
    from .MergeMeshes import MergeMeshes
    from .MergeROIs import MergeROIs
    from .GenerateSphere import GenerateSphere
    from .RigidToQuatEngine import RigidToQuatEngine
    from .TransformPosition import TransformPosition
    from .MeshClosingEngine import MeshClosingEngine
    from .DisplacementTransformEngine import DisplacementTransformEngine
    from .MeshSubsetEngine import MeshSubsetEngine
    from .ComputeWeightEngine import ComputeWeightEngine
    from .TextureInterpolation import TextureInterpolation
    from .AverageCoord import AverageCoord
    from .TopologyGaussPointSampler import TopologyGaussPointSampler
    from .RandomPointDistributionInSurface import RandomPointDistributionInSurface
    from .NormalsFromPoints import NormalsFromPoints
    from .MeshBarycentricMapperEngine import MeshBarycentricMapperEngine
    from .ComplementaryROI import ComplementaryROI
    from .MergeSets import MergeSets
    from .ValuesFromIndices import ValuesFromIndices
    from .DilateEngine import DilateEngine
    from .ValuesFromPositions import ValuesFromPositions
    from .ContractionInitialization import ContractionInitialization
    from .SphereROI import SphereROI
    from .SumEngine import SumEngine
    from .MeshROI import MeshROI
    from .ExtrudeEdgesAndGenerateQuads import ExtrudeEdgesAndGenerateQuads
    from .Vertex2Frame import Vertex2Frame
    from .TranslateTransformMatrixEngine import TranslateTransformMatrixEngine
    from .ROIValueMapper import ROIValueMapper
    from .IndicesFromValues import IndicesFromValues
    from .GenerateGrid import GenerateGrid
    from .PairBoxROI import PairBoxROI
    from .TransformEngine import TransformEngine
    from .DifferenceEngine import DifferenceEngine
    from .ShapeMatching import ShapeMatching
    from .DisplacementMatrixEngine import DisplacementMatrixEngine
    from .MeshSampler import MeshSampler
    from .Indices2ValuesMapper import Indices2ValuesMapper
    from .MergeVectors import MergeVectors
    from .QuatToRigidEngine import QuatToRigidEngine
    from .GaussPointSmoother import GaussPointSmoother
    from .GenerateRigidMass import GenerateRigidMass
    from .MeshSplittingEngine import MeshSplittingEngine
    from .MapIndices import MapIndices
    from .PlaneROI import PlaneROI
    from .NormEngine import NormEngine
    from .SubsetTopology import SubsetTopology
    from .Spiral import Spiral
    from .MathOp import MathOp
    from .ProjectiveTransformEngine import ProjectiveTransformEngine
    from .SelectConnectedLabelsROI import SelectConnectedLabelsROI
    from .MeshBoundaryROI import MeshBoundaryROI
    from .ClusteringEngine import ClusteringEngine
    from .PointsFromIndices import PointsFromIndices
    from .IndexValueMapper import IndexValueMapper
    from .ComputeDualQuatEngine import ComputeDualQuatEngine
    from .HausdorffDistance import HausdorffDistance
    from .BoxROI import BoxROI
    from .GaussPointContainer import GaussPointContainer
    from .MergePoints import MergePoints
    from .NearestPointROI import NearestPointROI
    from .PythonScriptDataEngine import PythonScriptDataEngine
    from .RotateTransformMatrixEngine import RotateTransformMatrixEngine
    from .SelectLabelROI import SelectLabelROI
    from .SmoothMeshEngine import SmoothMeshEngine
    from .JoinPoints import JoinPoints
    from .InvertTransformMatrixEngine import InvertTransformMatrixEngine
    from .GenerateCardiacCylinder import GenerateCardiacCylinder
    from .GroupFilterYoungModulus import GroupFilterYoungModulus



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component WriteState

.. autofunction:: WriteState

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def WriteState(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, writeX=None, writeX0=None, writeV=None, writeF=None, time=None, period=None, DOFsX=None, DOFsV=None, stopAt=None, keperiod=None, **kwargs):
    """
    Write State vectors to file at each timestep


    :param name: object name  Default value: WriteState

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param filename: output file name  Default value: 

    :param writeX: flag enabling output of X vector  Default value: 1

    :param writeX0: flag enabling output of X0 vector  Default value: 0

    :param writeV: flag enabling output of V vector  Default value: 0

    :param writeF: flag enabling output of F vector  Default value: 0

    :param time: set time to write outputs (by default export at t=0)  Default value: []

    :param period: period between outputs  Default value: 0.0

    :param DOFsX: set the position DOFs to write  Default value: []

    :param DOFsV: set the velocity DOFs to write  Default value: []

    :param stopAt: stop the simulation when the given threshold is reached  Default value: 0.0

    :param keperiod: set the period to measure the kinetic energy increase  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, writeX=writeX, writeX0=writeX0, writeV=writeV, writeF=writeF, time=time, period=period, DOFsX=DOFsX, DOFsV=DOFsV, stopAt=stopAt, keperiod=keperiod)
    return "WriteState", params



# -*- coding: utf-8 -*-


"""
Module ForceField

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    LennardJonesForceField

    HexahedralFEMForceField

    PlaneForceField

    TriangularQuadraticSpringsForceField

    CostaForceField

    TriangleFEMForceField

    BaseConstraintForceField

    InteractionEllipsoidForceField

    EdgePressureForceField

    TriangularFEMForceField

    VolumeRegional

    DiagonalVelocityDampingForceField

    TorsionForceField

    TriangularTensorMassForceField

    FastTriangularBendingSprings

    ConicalForceField

    TrianglePressureForceField

    ContractionForceField

    EllipsoidForceField

    TriangularBiquadraticSpringsForceField

    LinearForceField

    SurfacePressureForceField

    FastTetrahedralCorotationalForceField

    TetrahedronDiffusionFEMForceField

    MechanicalMatrixMapper

    TriangularBendingSprings

    TetrahedralTensorMassForceField

    FlexibleCorotationalFEMForceField

    FlexibleCorotationalMeshFEMForceField

    TriangularAnisotropicFEMForceField

    PressureConstraintForceField

    BoxStiffSpringForceField

    TetrahedronFEMForceField

    TriangularFEMForceFieldOptim

    QuadularBendingSprings

    StandardTetrahedralFEMForceField

    RestShapeSpringsForceField

    QuadPressureForceField

    SphereForceField

    TetrahedronHyperelasticityFEMForceField

    MappingGeometricStiffnessForceField

    TetrahedralCorotationalFEMForceField

    MRForceField

    OscillatingTorsionPressureForceField

    ConstantForceField

    ContractionCouplingForceField

    UniformVelocityDampingForceField

    HexahedronFEMForceField

    TaitSurfacePressureForceField



Content:
========

.. automodule::

    LennardJonesForceField

    HexahedralFEMForceField

    PlaneForceField

    TriangularQuadraticSpringsForceField

    CostaForceField

    TriangleFEMForceField

    BaseConstraintForceField

    InteractionEllipsoidForceField

    EdgePressureForceField

    TriangularFEMForceField

    VolumeRegional

    DiagonalVelocityDampingForceField

    TorsionForceField

    TriangularTensorMassForceField

    FastTriangularBendingSprings

    ConicalForceField

    TrianglePressureForceField

    ContractionForceField

    EllipsoidForceField

    TriangularBiquadraticSpringsForceField

    LinearForceField

    SurfacePressureForceField

    FastTetrahedralCorotationalForceField

    TetrahedronDiffusionFEMForceField

    MechanicalMatrixMapper

    TriangularBendingSprings

    TetrahedralTensorMassForceField

    FlexibleCorotationalFEMForceField

    FlexibleCorotationalMeshFEMForceField

    TriangularAnisotropicFEMForceField

    PressureConstraintForceField

    BoxStiffSpringForceField

    TetrahedronFEMForceField

    TriangularFEMForceFieldOptim

    QuadularBendingSprings

    StandardTetrahedralFEMForceField

    RestShapeSpringsForceField

    QuadPressureForceField

    SphereForceField

    TetrahedronHyperelasticityFEMForceField

    MappingGeometricStiffnessForceField

    TetrahedralCorotationalFEMForceField

    MRForceField

    OscillatingTorsionPressureForceField

    ConstantForceField

    ContractionCouplingForceField

    UniformVelocityDampingForceField

    HexahedronFEMForceField

    TaitSurfacePressureForceField



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['LennardJonesForceField', 'HexahedralFEMForceField', 'PlaneForceField', 'TriangularQuadraticSpringsForceField', 'CostaForceField', 'TriangleFEMForceField', 'BaseConstraintForceField', 'InteractionEllipsoidForceField', 'EdgePressureForceField', 'TriangularFEMForceField', 'VolumeRegional', 'DiagonalVelocityDampingForceField', 'TorsionForceField', 'TriangularTensorMassForceField', 'FastTriangularBendingSprings', 'ConicalForceField', 'TrianglePressureForceField', 'ContractionForceField', 'EllipsoidForceField', 'TriangularBiquadraticSpringsForceField', 'LinearForceField', 'SurfacePressureForceField', 'FastTetrahedralCorotationalForceField', 'TetrahedronDiffusionFEMForceField', 'MechanicalMatrixMapper', 'TriangularBendingSprings', 'TetrahedralTensorMassForceField', 'FlexibleCorotationalFEMForceField', 'FlexibleCorotationalMeshFEMForceField', 'TriangularAnisotropicFEMForceField', 'PressureConstraintForceField', 'BoxStiffSpringForceField', 'TetrahedronFEMForceField', 'TriangularFEMForceFieldOptim', 'QuadularBendingSprings', 'StandardTetrahedralFEMForceField', 'RestShapeSpringsForceField', 'QuadPressureForceField', 'SphereForceField', 'TetrahedronHyperelasticityFEMForceField', 'MappingGeometricStiffnessForceField', 'TetrahedralCorotationalFEMForceField', 'MRForceField', 'OscillatingTorsionPressureForceField', 'ConstantForceField', 'ContractionCouplingForceField', 'UniformVelocityDampingForceField', 'HexahedronFEMForceField', 'TaitSurfacePressureForceField']
class ForceField:
    from .LennardJonesForceField import LennardJonesForceField
    from .HexahedralFEMForceField import HexahedralFEMForceField
    from .PlaneForceField import PlaneForceField
    from .TriangularQuadraticSpringsForceField import TriangularQuadraticSpringsForceField
    from .CostaForceField import CostaForceField
    from .TriangleFEMForceField import TriangleFEMForceField
    from .BaseConstraintForceField import BaseConstraintForceField
    from .InteractionEllipsoidForceField import InteractionEllipsoidForceField
    from .EdgePressureForceField import EdgePressureForceField
    from .TriangularFEMForceField import TriangularFEMForceField
    from .VolumeRegional import VolumeRegional
    from .DiagonalVelocityDampingForceField import DiagonalVelocityDampingForceField
    from .TorsionForceField import TorsionForceField
    from .TriangularTensorMassForceField import TriangularTensorMassForceField
    from .FastTriangularBendingSprings import FastTriangularBendingSprings
    from .ConicalForceField import ConicalForceField
    from .TrianglePressureForceField import TrianglePressureForceField
    from .ContractionForceField import ContractionForceField
    from .EllipsoidForceField import EllipsoidForceField
    from .TriangularBiquadraticSpringsForceField import TriangularBiquadraticSpringsForceField
    from .LinearForceField import LinearForceField
    from .SurfacePressureForceField import SurfacePressureForceField
    from .FastTetrahedralCorotationalForceField import FastTetrahedralCorotationalForceField
    from .TetrahedronDiffusionFEMForceField import TetrahedronDiffusionFEMForceField
    from .MechanicalMatrixMapper import MechanicalMatrixMapper
    from .TriangularBendingSprings import TriangularBendingSprings
    from .TetrahedralTensorMassForceField import TetrahedralTensorMassForceField
    from .FlexibleCorotationalFEMForceField import FlexibleCorotationalFEMForceField
    from .FlexibleCorotationalMeshFEMForceField import FlexibleCorotationalMeshFEMForceField
    from .TriangularAnisotropicFEMForceField import TriangularAnisotropicFEMForceField
    from .PressureConstraintForceField import PressureConstraintForceField
    from .BoxStiffSpringForceField import BoxStiffSpringForceField
    from .TetrahedronFEMForceField import TetrahedronFEMForceField
    from .TriangularFEMForceFieldOptim import TriangularFEMForceFieldOptim
    from .QuadularBendingSprings import QuadularBendingSprings
    from .StandardTetrahedralFEMForceField import StandardTetrahedralFEMForceField
    from .RestShapeSpringsForceField import RestShapeSpringsForceField
    from .QuadPressureForceField import QuadPressureForceField
    from .SphereForceField import SphereForceField
    from .TetrahedronHyperelasticityFEMForceField import TetrahedronHyperelasticityFEMForceField
    from .MappingGeometricStiffnessForceField import MappingGeometricStiffnessForceField
    from .TetrahedralCorotationalFEMForceField import TetrahedralCorotationalFEMForceField
    from .MRForceField import MRForceField
    from .OscillatingTorsionPressureForceField import OscillatingTorsionPressureForceField
    from .ConstantForceField import ConstantForceField
    from .ContractionCouplingForceField import ContractionCouplingForceField
    from .UniformVelocityDampingForceField import UniformVelocityDampingForceField
    from .HexahedronFEMForceField import HexahedronFEMForceField
    from .TaitSurfacePressureForceField import TaitSurfacePressureForceField



import os
import subprocess

def start(sofa_path=None):
    if sofa_path is None:
        sofa_path = os.environ["CARDIAC_SOFA_PATH"]
    subprocess.call([sofa_path, os.path.join(os.path.dirname(__file__), "scene.py"), "-g", "batch"])


if __name__=="__main__":
    start()


# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component LCPConstraintSolver

.. autofunction:: LCPConstraintSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def LCPConstraintSolver(self, tolerance=None, maxIt=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, displayDebug=None, displayTime=None, initial_guess=None, build_lcp=None, mu=None, minW=None, maxF=None, multi_grid=None, multi_grid_levels=None, merge_method=None, merge_spatial_step=None, merge_local_levels=None, group=None, graph=None, showLevels=None, showCellWidth=None, showTranslation=None, showLevelTranslation=None, **kwargs):
    """
    A Constraint Solver using the Linear Complementarity Problem formulation to solve BaseConstraint based components


    :param name: object name  Default value: LCPConstraintSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param displayDebug: Display debug information.  Default value: 0

    :param displayTime: Display time for each important step of LCPConstraintSolver.  Default value: 0

    :param initial_guess: activate LCP results history to improve its resolution performances.  Default value: 1

    :param build_lcp: LCP is not fully built to increase performance in some case.  Default value: 1

    :param tolerance: residual error threshold for termination of the Gauss-Seidel algorithm  Default value: 0.001

    :param maxIt: maximal number of iterations of the Gauss-Seidel algorithm  Default value: 1000

    :param mu: Friction coefficient  Default value: 0.6

    :param minW: If not zero, constraints whose self-compliance (i.e. the corresponding value on the diagonal of W) is smaller than this threshold will be ignored  Default value: 0.0

    :param maxF: If not zero, constraints whose response force becomes larger than this threshold will be ignored  Default value: 0.0

    :param multi_grid: activate multi_grid resolution (NOT STABLE YET)  Default value: 0

    :param multi_grid_levels: if multi_grid is active: how many levels to create (>=2)  Default value: 2

    :param merge_method: if multi_grid is active: which method to use to merge constraints (0 = compliance-based, 1 = spatial coordinates)  Default value: 0

    :param merge_spatial_step: if merge_method is 1: grid size reduction between multigrid levels  Default value: 2

    :param merge_local_levels: if merge_method is 1: up to the specified level of the multigrid, constraints are grouped locally, i.e. separately within each contact pairs, while on upper levels they are grouped globally independently of contact pairs.  Default value: 2

    :param group: list of ID of groups of constraints to be handled by this solver.  Default value: [[0]]

    :param graph: Graph of residuals at each iteration  Default value: 

    :param showLevels: Number of constraint levels to display  Default value: 0

    :param showCellWidth: Distance between each constraint cells  Default value: 0.0

    :param showTranslation: Position of the first cell  Default value: [[0.0, 0.0, 0.0]]

    :param showLevelTranslation: Translation between levels  Default value: [[0.0, 0.0, 0.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, displayDebug=displayDebug, displayTime=displayTime, initial_guess=initial_guess, build_lcp=build_lcp, tolerance=tolerance, maxIt=maxIt, mu=mu, minW=minW, maxF=maxF, multi_grid=multi_grid, multi_grid_levels=multi_grid_levels, merge_method=merge_method, merge_spatial_step=merge_spatial_step, merge_local_levels=merge_local_levels, group=group, graph=graph, showLevels=showLevels, showCellWidth=showCellWidth, showTranslation=showTranslation, showLevelTranslation=showLevelTranslation)
    return "LCPConstraintSolver", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SelectConnectedLabelsROI

.. autofunction:: SelectConnectedLabelsROI

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SelectConnectedLabelsROI(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, nbLabels=None, connectLabels=None, indices=None, **kwargs):
    """
    Select a subset of points or cells labeled from different sources, that are connected given a list of connection pairs


    :param name: object name  Default value: SelectConnectedLabelsROI

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param nbLabels: number of label lists  Default value: 0

    :param connectLabels: Pairs of label to be connected accross different label lists  Default value: []

    :param indices: selected point/cell indices  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, nbLabels=nbLabels, connectLabels=connectLabels, indices=indices)
    return "SelectConnectedLabelsROI", params



# -*- coding: utf-8 -*-


"""
Module VisualModel

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    OglIntVector4Variable

    CompositingVisualLoop

    DirectionalLight

    PostProcessManager

    OglFloatVector2Variable

    OglMatrix2x4Variable

    OglIntVectorVariable

    OglFloat2Variable

    OglShadowShader

    OglMatrix2Variable

    OglFloatVectorVariable

    OglFloat4Attribute

    OglInt4Attribute

    OglSceneFrame

    OglTexture2D

    OrderIndependentTransparencyManager

    VisualModelImpl

    OglMatrix3x4Variable

    OglMatrix4x3Variable

    OglFloat4Variable

    OglInt4Variable

    VisualManagerSecondaryPass

    OglInt2Variable

    VisualTransform

    MergeVisualModels

    PointSplatModel

    OglFloat3Variable

    OglIntVector3Variable

    OglFloatVector3Variable

    OglInt3Attribute

    OglUIntAttribute

    OglShader

    OglUInt4Attribute

    ClipPlane

    OglIntAttribute

    OglTexture

    OglColorMap

    OglIntVariable

    OglGrid

    PositionalLight

    LightManager

    VisualManagerPass

    OglUInt3Attribute

    SpotLight

    OglOITShader

    OglTexturePointer

    OglMatrix4Variable

    OglInt2Attribute

    Visual3DText

    OglLineAxis

    OglLabel

    OglIntVector2Variable

    OglFloatAttribute

    OglFloatVariable

    OglFloatVector4Variable

    DataDisplay

    OglMatrix2x3Variable

    DefaultVisualManagerLoop

    OglInt3Variable

    SlicedVolumetricModel

    OglRenderingSRGB

    OglFloat2Attribute

    OglMatrix4VectorVariable

    OglFloat3Attribute

    OglCylinderModel

    VisualStyle

    OglUInt2Attribute

    OglShaderVisualModel

    OglViewport

    OglModel

    OglMatrix3x2Variable

    OglMatrix4x2Variable

    OglMatrix3Variable



Content:
========

.. automodule::

    OglIntVector4Variable

    CompositingVisualLoop

    DirectionalLight

    PostProcessManager

    OglFloatVector2Variable

    OglMatrix2x4Variable

    OglIntVectorVariable

    OglFloat2Variable

    OglShadowShader

    OglMatrix2Variable

    OglFloatVectorVariable

    OglFloat4Attribute

    OglInt4Attribute

    OglSceneFrame

    OglTexture2D

    OrderIndependentTransparencyManager

    VisualModelImpl

    OglMatrix3x4Variable

    OglMatrix4x3Variable

    OglFloat4Variable

    OglInt4Variable

    VisualManagerSecondaryPass

    OglInt2Variable

    VisualTransform

    MergeVisualModels

    PointSplatModel

    OglFloat3Variable

    OglIntVector3Variable

    OglFloatVector3Variable

    OglInt3Attribute

    OglUIntAttribute

    OglShader

    OglUInt4Attribute

    ClipPlane

    OglIntAttribute

    OglTexture

    OglColorMap

    OglIntVariable

    OglGrid

    PositionalLight

    LightManager

    VisualManagerPass

    OglUInt3Attribute

    SpotLight

    OglOITShader

    OglTexturePointer

    OglMatrix4Variable

    OglInt2Attribute

    Visual3DText

    OglLineAxis

    OglLabel

    OglIntVector2Variable

    OglFloatAttribute

    OglFloatVariable

    OglFloatVector4Variable

    DataDisplay

    OglMatrix2x3Variable

    DefaultVisualManagerLoop

    OglInt3Variable

    SlicedVolumetricModel

    OglRenderingSRGB

    OglFloat2Attribute

    OglMatrix4VectorVariable

    OglFloat3Attribute

    OglCylinderModel

    VisualStyle

    OglUInt2Attribute

    OglShaderVisualModel

    OglViewport

    OglModel

    OglMatrix3x2Variable

    OglMatrix4x2Variable

    OglMatrix3Variable



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['OglIntVector4Variable', 'CompositingVisualLoop', 'DirectionalLight', 'PostProcessManager', 'OglFloatVector2Variable', 'OglMatrix2x4Variable', 'OglIntVectorVariable', 'OglFloat2Variable', 'OglShadowShader', 'OglMatrix2Variable', 'OglFloatVectorVariable', 'OglFloat4Attribute', 'OglInt4Attribute', 'OglSceneFrame', 'OglTexture2D', 'OrderIndependentTransparencyManager', 'VisualModelImpl', 'OglMatrix3x4Variable', 'OglMatrix4x3Variable', 'OglFloat4Variable', 'OglInt4Variable', 'VisualManagerSecondaryPass', 'OglInt2Variable', 'VisualTransform', 'MergeVisualModels', 'PointSplatModel', 'OglFloat3Variable', 'OglIntVector3Variable', 'OglFloatVector3Variable', 'OglInt3Attribute', 'OglUIntAttribute', 'OglShader', 'OglUInt4Attribute', 'ClipPlane', 'OglIntAttribute', 'OglTexture', 'OglColorMap', 'OglIntVariable', 'OglGrid', 'PositionalLight', 'LightManager', 'VisualManagerPass', 'OglUInt3Attribute', 'SpotLight', 'OglOITShader', 'OglTexturePointer', 'OglMatrix4Variable', 'OglInt2Attribute', 'Visual3DText', 'OglLineAxis', 'OglLabel', 'OglIntVector2Variable', 'OglFloatAttribute', 'OglFloatVariable', 'OglFloatVector4Variable', 'DataDisplay', 'OglMatrix2x3Variable', 'DefaultVisualManagerLoop', 'OglInt3Variable', 'SlicedVolumetricModel', 'OglRenderingSRGB', 'OglFloat2Attribute', 'OglMatrix4VectorVariable', 'OglFloat3Attribute', 'OglCylinderModel', 'VisualStyle', 'OglUInt2Attribute', 'OglShaderVisualModel', 'OglViewport', 'OglModel', 'OglMatrix3x2Variable', 'OglMatrix4x2Variable', 'OglMatrix3Variable']
class VisualModel:
    from .OglIntVector4Variable import OglIntVector4Variable
    from .CompositingVisualLoop import CompositingVisualLoop
    from .DirectionalLight import DirectionalLight
    from .PostProcessManager import PostProcessManager
    from .OglFloatVector2Variable import OglFloatVector2Variable
    from .OglMatrix2x4Variable import OglMatrix2x4Variable
    from .OglIntVectorVariable import OglIntVectorVariable
    from .OglFloat2Variable import OglFloat2Variable
    from .OglShadowShader import OglShadowShader
    from .OglMatrix2Variable import OglMatrix2Variable
    from .OglFloatVectorVariable import OglFloatVectorVariable
    from .OglFloat4Attribute import OglFloat4Attribute
    from .OglInt4Attribute import OglInt4Attribute
    from .OglSceneFrame import OglSceneFrame
    from .OglTexture2D import OglTexture2D
    from .OrderIndependentTransparencyManager import OrderIndependentTransparencyManager
    from .VisualModelImpl import VisualModelImpl
    from .OglMatrix3x4Variable import OglMatrix3x4Variable
    from .OglMatrix4x3Variable import OglMatrix4x3Variable
    from .OglFloat4Variable import OglFloat4Variable
    from .OglInt4Variable import OglInt4Variable
    from .VisualManagerSecondaryPass import VisualManagerSecondaryPass
    from .OglInt2Variable import OglInt2Variable
    from .VisualTransform import VisualTransform
    from .MergeVisualModels import MergeVisualModels
    from .PointSplatModel import PointSplatModel
    from .OglFloat3Variable import OglFloat3Variable
    from .OglIntVector3Variable import OglIntVector3Variable
    from .OglFloatVector3Variable import OglFloatVector3Variable
    from .OglInt3Attribute import OglInt3Attribute
    from .OglUIntAttribute import OglUIntAttribute
    from .OglShader import OglShader
    from .OglUInt4Attribute import OglUInt4Attribute
    from .ClipPlane import ClipPlane
    from .OglIntAttribute import OglIntAttribute
    from .OglTexture import OglTexture
    from .OglColorMap import OglColorMap
    from .OglIntVariable import OglIntVariable
    from .OglGrid import OglGrid
    from .PositionalLight import PositionalLight
    from .LightManager import LightManager
    from .VisualManagerPass import VisualManagerPass
    from .OglUInt3Attribute import OglUInt3Attribute
    from .SpotLight import SpotLight
    from .OglOITShader import OglOITShader
    from .OglTexturePointer import OglTexturePointer
    from .OglMatrix4Variable import OglMatrix4Variable
    from .OglInt2Attribute import OglInt2Attribute
    from .Visual3DText import Visual3DText
    from .OglLineAxis import OglLineAxis
    from .OglLabel import OglLabel
    from .OglIntVector2Variable import OglIntVector2Variable
    from .OglFloatAttribute import OglFloatAttribute
    from .OglFloatVariable import OglFloatVariable
    from .OglFloatVector4Variable import OglFloatVector4Variable
    from .DataDisplay import DataDisplay
    from .OglMatrix2x3Variable import OglMatrix2x3Variable
    from .DefaultVisualManagerLoop import DefaultVisualManagerLoop
    from .OglInt3Variable import OglInt3Variable
    from .SlicedVolumetricModel import SlicedVolumetricModel
    from .OglRenderingSRGB import OglRenderingSRGB
    from .OglFloat2Attribute import OglFloat2Attribute
    from .OglMatrix4VectorVariable import OglMatrix4VectorVariable
    from .OglFloat3Attribute import OglFloat3Attribute
    from .OglCylinderModel import OglCylinderModel
    from .VisualStyle import VisualStyle
    from .OglUInt2Attribute import OglUInt2Attribute
    from .OglShaderVisualModel import OglShaderVisualModel
    from .OglViewport import OglViewport
    from .OglModel import OglModel
    from .OglMatrix3x2Variable import OglMatrix3x2Variable
    from .OglMatrix4x2Variable import OglMatrix4x2Variable
    from .OglMatrix3Variable import OglMatrix3Variable



# -*- coding: utf-8 -*-


"""
Module OdeSolver

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    EulerImplicitSolver

    RungeKutta2Solver

    CentralDifferenceSolver

    StaticSolver

    DampVelocitySolver

    RungeKutta4Solver

    NewmarkImplicitSolver

    VariationalSymplecticSolver

    EulerExplicitSolver



Content:
========

.. automodule::

    EulerImplicitSolver

    RungeKutta2Solver

    CentralDifferenceSolver

    StaticSolver

    DampVelocitySolver

    RungeKutta4Solver

    NewmarkImplicitSolver

    VariationalSymplecticSolver

    EulerExplicitSolver



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['EulerImplicitSolver', 'RungeKutta2Solver', 'CentralDifferenceSolver', 'StaticSolver', 'DampVelocitySolver', 'RungeKutta4Solver', 'NewmarkImplicitSolver', 'VariationalSymplecticSolver', 'EulerExplicitSolver']
class OdeSolver:
    from .EulerImplicitSolver import EulerImplicitSolver
    from .RungeKutta2Solver import RungeKutta2Solver
    from .CentralDifferenceSolver import CentralDifferenceSolver
    from .StaticSolver import StaticSolver
    from .DampVelocitySolver import DampVelocitySolver
    from .RungeKutta4Solver import RungeKutta4Solver
    from .NewmarkImplicitSolver import NewmarkImplicitSolver
    from .VariationalSymplecticSolver import VariationalSymplecticSolver
    from .EulerExplicitSolver import EulerExplicitSolver



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglUInt4Attribute

.. autofunction:: OglUInt4Attribute

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglUInt4Attribute(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, id=None, indexShader=None, value=None, handleDynamicTopology=None, **kwargs):
    """
    OglUInt4Attribute


    :param name: object name  Default value: OglUInt4Attribute

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param id: Set an ID name  Default value: 

    :param indexShader: Set the index of the desired shader you want to apply this parameter  Default value: 0

    :param value: internal Data  Default value: []

    :param handleDynamicTopology: Activate handling of topological changes on the values of this attribute (resizes only)  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, id=id, indexShader=indexShader, value=value, handleDynamicTopology=handleDynamicTopology)
    return "OglUInt4Attribute", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ShewchukPCGLinearSolver

.. autofunction:: ShewchukPCGLinearSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ShewchukPCGLinearSolver(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, iterations=None, tolerance=None, use_precond=None, update_step=None, build_precond=None, preconditioners=None, graph=None, **kwargs):
    """
    Linear system solver using the conjugate gradient iterative algorithm


    :param name: object name  Default value: ShewchukPCGLinearSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param iterations: maximum number of iterations of the Conjugate Gradient solution  Default value: 25

    :param tolerance: desired precision of the Conjugate Gradient Solution (ratio of current residual norm over initial residual norm)  Default value: 1e-05

    :param use_precond: Use preconditioner  Default value: 1

    :param update_step: Number of steps before the next refresh of precondtioners  Default value: 1

    :param build_precond: Build the preconditioners, if false build the preconditioner only at the initial step  Default value: 1

    :param preconditioners: If not empty: path to the solvers to use as preconditioners  Default value: 

    :param graph: Graph of residuals at each iteration  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, iterations=iterations, tolerance=tolerance, use_precond=use_precond, update_step=update_step, build_precond=build_precond, preconditioners=preconditioners, graph=graph)
    return "ShewchukPCGLinearSolver", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SparseGridRamificationTopology

.. autofunction:: SparseGridRamificationTopology

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SparseGridRamificationTopology(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, position=None, edges=None, triangles=None, quads=None, tetrahedra=None, hexahedra=None, uv=None, drawEdges=None, drawTriangles=None, drawQuads=None, drawTetrahedra=None, drawHexahedra=None, fillWeighted=None, onlyInsideCells=None, n=None, min=None, max=None, cellWidth=None, nbVirtualFinerLevels=None, dataResolution=None, voxelSize=None, marchingCubeStep=None, convolutionSize=None, facets=None, finestConnectivity=None, **kwargs):
    """
    Sparse grid in 3D (modified)


    :param name: object name  Default value: SparseGridRamificationTopology

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Filename of the mesh  Default value: 

    :param position: List of point positions  Default value: []

    :param edges: List of edge indices  Default value: []

    :param triangles: List of triangle indices  Default value: []

    :param quads: List of quad indices  Default value: []

    :param tetrahedra: List of tetrahedron indices  Default value: []

    :param hexahedra: List of hexahedron indices  Default value: []

    :param uv: List of uv coordinates  Default value: []

    :param drawEdges: if true, draw the topology Edges  Default value: 0

    :param drawTriangles: if true, draw the topology Triangles  Default value: 0

    :param drawQuads: if true, draw the topology Quads  Default value: 0

    :param drawTetrahedra: if true, draw the topology Tetrahedra  Default value: 0

    :param drawHexahedra: if true, draw the topology hexahedra  Default value: 0

    :param fillWeighted: Is quantity of matter inside a cell taken into account? (.5 for boundary, 1 for inside)  Default value: 1

    :param onlyInsideCells: Select only inside cells (exclude boundary cells)  Default value: 0

    :param n: grid resolution  Default value: [[2, 2, 2]]

    :param min: Min  Default value: [[0.0, 0.0, 0.0]]

    :param max: Max  Default value: [[0.0, 0.0, 0.0]]

    :param cellWidth: if > 0 : dimension of each cell in the created grid  Default value: 0.0

    :param nbVirtualFinerLevels: create virtual (not in the animation tree) finer sparse grids in order to dispose of finest information (usefull to compute better mechanical properties for example)  Default value: 0

    :param dataResolution: Dimension of the voxel File  Default value: [[0, 0, 0]]

    :param voxelSize: Dimension of one voxel  Default value: [[1.0, 1.0, 1.0]]

    :param marchingCubeStep: Step of the Marching Cube algorithm  Default value: 1

    :param convolutionSize: Dimension of the convolution kernel to smooth the voxels. 0 if no smoothing is required.  Default value: 0

    :param facets: Input mesh facets  Default value: []

    :param finestConnectivity: Test for connectivity at the finest level? (more precise but slower by testing all intersections between the model mesh and the faces between boundary cubes)  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, position=position, edges=edges, triangles=triangles, quads=quads, tetrahedra=tetrahedra, hexahedra=hexahedra, uv=uv, drawEdges=drawEdges, drawTriangles=drawTriangles, drawQuads=drawQuads, drawTetrahedra=drawTetrahedra, drawHexahedra=drawHexahedra, fillWeighted=fillWeighted, onlyInsideCells=onlyInsideCells, n=n, min=min, max=max, cellWidth=cellWidth, nbVirtualFinerLevels=nbVirtualFinerLevels, dataResolution=dataResolution, voxelSize=voxelSize, marchingCubeStep=marchingCubeStep, convolutionSize=convolutionSize, facets=facets, finestConnectivity=finestConnectivity)
    return "SparseGridRamificationTopology", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshClosingEngine

.. autofunction:: MeshClosingEngine

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshClosingEngine(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, inputPosition=None, inputTriangles=None, inputQuads=None, position=None, triangles=None, quads=None, indices=None, closingPosition=None, closingTriangles=None, **kwargs):
    """
    Merge several meshes


    :param name: object name  Default value: MeshClosingEngine

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param inputPosition: input vertices  Default value: []

    :param inputTriangles: input triangles  Default value: []

    :param inputQuads: input quads  Default value: []

    :param position: Vertices of closed mesh  Default value: []

    :param triangles: Triangles of closed mesh  Default value: []

    :param quads: Quads of closed mesh (=input quads with current method)  Default value: []

    :param indices: Index lists of the closing parts  Default value: 

    :param closingPosition: Vertices of the closing parts  Default value: []

    :param closingTriangles: Triangles of the closing parts  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, inputPosition=inputPosition, inputTriangles=inputTriangles, inputQuads=inputQuads, position=position, triangles=triangles, quads=quads, indices=indices, closingPosition=closingPosition, closingTriangles=closingTriangles)
    return "MeshClosingEngine", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GenerateRigidMass

.. autofunction:: GenerateRigidMass

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GenerateRigidMass(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, density=None, position=None, triangles=None, quads=None, polygons=None, rigidMass=None, mass=None, volume=None, inertiaMatrix=None, massCenter=None, centerToOrigin=None, **kwargs):
    """
    An engine computing the RigidMass of a mesh : mass, volume and inertia matrix.


    :param name: object name  Default value: GenerateRigidMass

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param density: input: Density of the object  Default value: 1000.0

    :param position: input: positions of the vertices  Default value: []

    :param triangles: input: triangles of the mesh  Default value: []

    :param quads: input: quads of the mesh  Default value: []

    :param polygons: input: polygons of the mesh  Default value: []

    :param rigidMass: output: rigid mass computed  Default value: 1 1 [1 0 0,0 1 0,0 0 1]

    :param mass: output: mass of the mesh  Default value: 0.0

    :param volume: output: volume of the mesh  Default value: 0.0

    :param inertiaMatrix: output: the inertia matrix of the mesh  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param massCenter: output: the gravity center of the mesh  Default value: [[0.0, 0.0, 0.0]]

    :param centerToOrigin: output: vector going from the mass center to the space origin  Default value: [[0.0, 0.0, 0.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, density=density, position=position, triangles=triangles, quads=quads, polygons=polygons, rigidMass=rigidMass, mass=mass, volume=volume, inertiaMatrix=inertiaMatrix, massCenter=massCenter, centerToOrigin=centerToOrigin)
    return "GenerateRigidMass", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component HexahedronCompositeFEMForceFieldAndMass

.. autofunction:: HexahedronCompositeFEMForceFieldAndMass

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def HexahedronCompositeFEMForceFieldAndMass(self, poissonRatio=None, youngModulus=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, separateGravity=None, rayleighMass=None, method=None, updateStiffnessMatrix=None, assembling=None, gatherPt=None, gatherBsize=None, drawing=None, drawPercentageOffset=None, stiffnessMatrices=None, initialPoints=None, massMatrices=None, density=None, lumpedMass=None, nbVirtualFinerLevels=None, useMass=None, totalMass=None, finestToCoarse=None, homogenizationMethod=None, completeInterpolation=None, useRamification=None, drawType=None, drawColor=None, drawSize=None, **kwargs):
    """
    Non uniform Hexahedral finite elements


    :param name: object name  Default value: HexahedronCompositeFEMForceFieldAndMass

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param separateGravity: add separately gravity to velocity computation  Default value: 0

    :param rayleighMass: Rayleigh damping - mass matrix coefficient  Default value: 0.0

    :param method: "large" or "polar" or "small" displacements  Default value: large

    :param poissonRatio: (No help available)  Default value: 0.449999988079

    :param youngModulus: (No help available)  Default value: 5000.0

    :param updateStiffnessMatrix: (No help available)  Default value: 0

    :param assembling: (No help available)  Default value: 0

    :param gatherPt: number of dof accumulated per threads during the gather operation (Only use in GPU version)  Default value:  

    :param gatherBsize: number of dof accumulated per threads during the gather operation (Only use in GPU version)  Default value:  

    :param drawing:  draw the forcefield if true  Default value: 1

    :param drawPercentageOffset: size of the hexa  Default value: 0.15

    :param stiffnessMatrices: Stiffness matrices per element (K_i)  Default value: []

    :param initialPoints: Initial Position  Default value: []

    :param massMatrices: Mass matrices per element (M_i)  Default value: []

    :param density: density == volumetric mass in english (kg.m-3)  Default value: 1.0

    :param lumpedMass: Does it use lumped masses?  Default value: 0

    :param nbVirtualFinerLevels: use virtual finer levels, in order to compte non-uniform stiffness  Default value: 0

    :param useMass: Using this ForceField like a Mass? (rather than using a separated Mass)  Default value: 1

    :param totalMass: (No help available)  Default value: 0.0

    :param finestToCoarse: Does the homogenization is done directly from the finest level to the coarse one?  Default value: 0

    :param homogenizationMethod: 0->static, 1->constrained static, 2->modal analysis  Default value: 0

    :param completeInterpolation: Is the non-linear, complete interpolation used?  Default value: 0

    :param useRamification: If SparseGridRamification, are ramifications taken into account?  Default value: 1

    :param drawType: (No help available)  Default value: 0

    :param drawColor: (No help available)  Default value: 0

    :param drawSize: (No help available)  Default value: -1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, separateGravity=separateGravity, rayleighMass=rayleighMass, method=method, poissonRatio=poissonRatio, youngModulus=youngModulus, updateStiffnessMatrix=updateStiffnessMatrix, assembling=assembling, gatherPt=gatherPt, gatherBsize=gatherBsize, drawing=drawing, drawPercentageOffset=drawPercentageOffset, stiffnessMatrices=stiffnessMatrices, initialPoints=initialPoints, massMatrices=massMatrices, density=density, lumpedMass=lumpedMass, nbVirtualFinerLevels=nbVirtualFinerLevels, useMass=useMass, totalMass=totalMass, finestToCoarse=finestToCoarse, homogenizationMethod=homogenizationMethod, completeInterpolation=completeInterpolation, useRamification=useRamification, drawType=drawType, drawColor=drawColor, drawSize=drawSize)
    return "HexahedronCompositeFEMForceFieldAndMass", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglLabel

.. autofunction:: OglLabel

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglLabel(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, prefix=None, label=None, suffix=None, x=None, y=None, fontsize=None, color=None, selectContrastingColor=None, updateLabelEveryNbSteps=None, visible=None, **kwargs):
    """
    Display 2D text in the viewport.


    :param name: object name  Default value: OglLabel

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param prefix: The prefix of the text to display  Default value: 

    :param label: The text to display  Default value: 

    :param suffix: The suffix of the text to display  Default value: 

    :param x: The x position of the text on the screen  Default value: 10

    :param y: The y position of the text on the screen  Default value: 10

    :param fontsize: The size of the font used to display the text on the screen  Default value: 14

    :param color: The color of the text to display. (default='gray')  Default value: [[0.5, 0.5, 0.5, 1.0]]

    :param selectContrastingColor: Overide the color value but one that contrast with the background color  Default value: 0

    :param updateLabelEveryNbSteps: Update the display of the label every nb of time steps  Default value: 0

    :param visible: Is label displayed  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, prefix=prefix, label=label, suffix=suffix, x=x, y=y, fontsize=fontsize, color=color, selectContrastingColor=selectContrastingColor, updateLabelEveryNbSteps=updateLabelEveryNbSteps, visible=visible)
    return "OglLabel", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ProjectivePressureConstraint

.. autofunction:: ProjectivePressureConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ProjectivePressureConstraint(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, group=None, endTime=None, optimiser=None, tagMeca=None, tagSolver=None, FFNames=None, phaseNew=None, updateSteps=None, **kwargs):
    """
    Correction the pressure force field for the heart ventricles


    :param name: object name  Default value: ProjectivePressureConstraint

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param group: ID of the group containing this constraint. This ID is used to specify which constraints are solved by which solver, by specifying in each solver which groups of constraints it should handle.  Default value: 0

    :param endTime: The constraint stops acting after the given value.
Use a negative value for infinite constraints  Default value: -1.0

    :param optimiser: if the correction should be optimized  Default value: 0

    :param tagMeca: tagMeca  Default value: meca

    :param tagSolver: Tag of the Solver Object  Default value: solver

    :param FFNames: Names of the pressure forcefields  Default value: []

    :param phaseNew: phaseNew  Default value: []

    :param updateSteps: the number of steps after which the projection should be updated  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, group=group, endTime=endTime, optimiser=optimiser, tagMeca=tagMeca, tagSolver=tagSolver, FFNames=FFNames, phaseNew=phaseNew, updateSteps=updateSteps)
    return "ProjectivePressureConstraint", params



# -*- coding: utf-8 -*-


"""
Module Controller

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    MechanicalStateController

    PythonScriptController

    EnergyMonitor

    NullForceFeedback

    NullForceFeedbackT

    GeometryMonitor



Content:
========

.. automodule::

    MechanicalStateController

    PythonScriptController

    EnergyMonitor

    NullForceFeedback

    NullForceFeedbackT

    GeometryMonitor



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['MechanicalStateController', 'PythonScriptController', 'EnergyMonitor', 'NullForceFeedback', 'NullForceFeedbackT', 'GeometryMonitor']
class Controller:
    from .MechanicalStateController import MechanicalStateController
    from .PythonScriptController import PythonScriptController
    from .EnergyMonitor import EnergyMonitor
    from .NullForceFeedback import NullForceFeedback
    from .NullForceFeedbackT import NullForceFeedbackT
    from .GeometryMonitor import GeometryMonitor



# -*- coding: utf-8 -*-


"""
Module TopologyObject

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    TetrahedronSetTopologyContainer

    TriangleSetTopologyAlgorithms

    EdgeSetGeometryAlgorithms

    EdgeSetTopologyContainer

    HexahedronSetTopologyAlgorithms

    EdgeSetTopologyModifier

    MultilevelHexahedronSetTopologyContainer

    TriangleSetGeometryAlgorithms

    PointSetTopologyModifier

    TetrahedronSetTopologyAlgorithms

    PointSetTopologyContainer

    QuadSetTopologyContainer

    TetrahedronSetTopologyModifier

    QuadSetGeometryAlgorithms

    DynamicSparseGridTopologyModifier

    HexahedronSetGeometryAlgorithms

    PointSetGeometryAlgorithms

    QuadSetTopologyAlgorithms

    PointSetTopologyAlgorithms

    QuadSetTopologyModifier

    TriangleSetTopologyContainer

    HexahedronSetTopologyContainer

    EdgeSetTopologyAlgorithms

    DynamicSparseGridGeometryAlgorithms

    TriangleSetTopologyModifier

    HexahedronSetTopologyModifier

    DynamicSparseGridTopologyAlgorithms

    TetrahedronSetGeometryAlgorithms

    DynamicSparseGridTopologyContainer



Content:
========

.. automodule::

    TetrahedronSetTopologyContainer

    TriangleSetTopologyAlgorithms

    EdgeSetGeometryAlgorithms

    EdgeSetTopologyContainer

    HexahedronSetTopologyAlgorithms

    EdgeSetTopologyModifier

    MultilevelHexahedronSetTopologyContainer

    TriangleSetGeometryAlgorithms

    PointSetTopologyModifier

    TetrahedronSetTopologyAlgorithms

    PointSetTopologyContainer

    QuadSetTopologyContainer

    TetrahedronSetTopologyModifier

    QuadSetGeometryAlgorithms

    DynamicSparseGridTopologyModifier

    HexahedronSetGeometryAlgorithms

    PointSetGeometryAlgorithms

    QuadSetTopologyAlgorithms

    PointSetTopologyAlgorithms

    QuadSetTopologyModifier

    TriangleSetTopologyContainer

    HexahedronSetTopologyContainer

    EdgeSetTopologyAlgorithms

    DynamicSparseGridGeometryAlgorithms

    TriangleSetTopologyModifier

    HexahedronSetTopologyModifier

    DynamicSparseGridTopologyAlgorithms

    TetrahedronSetGeometryAlgorithms

    DynamicSparseGridTopologyContainer



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['TetrahedronSetTopologyContainer', 'TriangleSetTopologyAlgorithms', 'EdgeSetGeometryAlgorithms', 'EdgeSetTopologyContainer', 'HexahedronSetTopologyAlgorithms', 'EdgeSetTopologyModifier', 'MultilevelHexahedronSetTopologyContainer', 'TriangleSetGeometryAlgorithms', 'PointSetTopologyModifier', 'TetrahedronSetTopologyAlgorithms', 'PointSetTopologyContainer', 'QuadSetTopologyContainer', 'TetrahedronSetTopologyModifier', 'QuadSetGeometryAlgorithms', 'DynamicSparseGridTopologyModifier', 'HexahedronSetGeometryAlgorithms', 'PointSetGeometryAlgorithms', 'QuadSetTopologyAlgorithms', 'PointSetTopologyAlgorithms', 'QuadSetTopologyModifier', 'TriangleSetTopologyContainer', 'HexahedronSetTopologyContainer', 'EdgeSetTopologyAlgorithms', 'DynamicSparseGridGeometryAlgorithms', 'TriangleSetTopologyModifier', 'HexahedronSetTopologyModifier', 'DynamicSparseGridTopologyAlgorithms', 'TetrahedronSetGeometryAlgorithms', 'DynamicSparseGridTopologyContainer']
class TopologyObject:
    from .TetrahedronSetTopologyContainer import TetrahedronSetTopologyContainer
    from .TriangleSetTopologyAlgorithms import TriangleSetTopologyAlgorithms
    from .EdgeSetGeometryAlgorithms import EdgeSetGeometryAlgorithms
    from .EdgeSetTopologyContainer import EdgeSetTopologyContainer
    from .HexahedronSetTopologyAlgorithms import HexahedronSetTopologyAlgorithms
    from .EdgeSetTopologyModifier import EdgeSetTopologyModifier
    from .MultilevelHexahedronSetTopologyContainer import MultilevelHexahedronSetTopologyContainer
    from .TriangleSetGeometryAlgorithms import TriangleSetGeometryAlgorithms
    from .PointSetTopologyModifier import PointSetTopologyModifier
    from .TetrahedronSetTopologyAlgorithms import TetrahedronSetTopologyAlgorithms
    from .PointSetTopologyContainer import PointSetTopologyContainer
    from .QuadSetTopologyContainer import QuadSetTopologyContainer
    from .TetrahedronSetTopologyModifier import TetrahedronSetTopologyModifier
    from .QuadSetGeometryAlgorithms import QuadSetGeometryAlgorithms
    from .DynamicSparseGridTopologyModifier import DynamicSparseGridTopologyModifier
    from .HexahedronSetGeometryAlgorithms import HexahedronSetGeometryAlgorithms
    from .PointSetGeometryAlgorithms import PointSetGeometryAlgorithms
    from .QuadSetTopologyAlgorithms import QuadSetTopologyAlgorithms
    from .PointSetTopologyAlgorithms import PointSetTopologyAlgorithms
    from .QuadSetTopologyModifier import QuadSetTopologyModifier
    from .TriangleSetTopologyContainer import TriangleSetTopologyContainer
    from .HexahedronSetTopologyContainer import HexahedronSetTopologyContainer
    from .EdgeSetTopologyAlgorithms import EdgeSetTopologyAlgorithms
    from .DynamicSparseGridGeometryAlgorithms import DynamicSparseGridGeometryAlgorithms
    from .TriangleSetTopologyModifier import TriangleSetTopologyModifier
    from .HexahedronSetTopologyModifier import HexahedronSetTopologyModifier
    from .DynamicSparseGridTopologyAlgorithms import DynamicSparseGridTopologyAlgorithms
    from .TetrahedronSetGeometryAlgorithms import TetrahedronSetGeometryAlgorithms
    from .DynamicSparseGridTopologyContainer import DynamicSparseGridTopologyContainer



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component AffineMovementConstraint

.. autofunction:: AffineMovementConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def AffineMovementConstraint(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, group=None, endTime=None, meshIndices=None, indices=None, beginConstraintTime=None, endConstraintTime=None, rotation=None, quaternion=None, translation=None, drawConstrainedPoints=None, **kwargs):
    """
    Constraint the movement by a rigid transform.


    :param name: object name  Default value: AffineMovementConstraint

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param group: ID of the group containing this constraint. This ID is used to specify which constraints are solved by which solver, by specifying in each solver which groups of constraints it should handle.  Default value: 0

    :param endTime: The constraint stops acting after the given value.
Use a negative value for infinite constraints  Default value: -1.0

    :param meshIndices: Indices of the mesh  Default value: []

    :param indices: Indices of the constrained points  Default value: []

    :param beginConstraintTime: Begin time of the bilinear constraint  Default value: 0.0

    :param endConstraintTime: End time of the bilinear constraint  Default value: 20.0

    :param rotation: rotation applied to border points  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param quaternion: quaternion applied to border points  Default value: [[0.0, 0.0, 0.0, 1.0]]

    :param translation: translation applied to border points  Default value: [[0.0, 0.0, 0.0]]

    :param drawConstrainedPoints: draw constrained points  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, group=group, endTime=endTime, meshIndices=meshIndices, indices=indices, beginConstraintTime=beginConstraintTime, endConstraintTime=endConstraintTime, rotation=rotation, quaternion=quaternion, translation=translation, drawConstrainedPoints=drawConstrainedPoints)
    return "AffineMovementConstraint", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshSplittingEngine

.. autofunction:: MeshSplittingEngine

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshSplittingEngine(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position=None, edges=None, triangles=None, quads=None, tetrahedra=None, hexahedra=None, nbInputs=None, indexPairs=None, position1=None, **kwargs):
    """
    This class breaks a mesh in multiple parts, based on selected vertices or cells.


    :param name: object name  Default value: MeshSplittingEngine

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param position: input vertices  Default value: []

    :param edges: input edges  Default value: []

    :param triangles: input triangles  Default value: []

    :param quads: input quads  Default value: []

    :param tetrahedra: input tetrahedra  Default value: []

    :param hexahedra: input hexahedra  Default value: []

    :param nbInputs: Number of input vectors  Default value: 0

    :param indexPairs: couples for input vertices: ROI index + index in the ROI  Default value: []

    :param position1: output vertices(1)  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position=position, edges=edges, triangles=triangles, quads=quads, tetrahedra=tetrahedra, hexahedra=hexahedra, nbInputs=nbInputs, indexPairs=indexPairs, position1=position1)
    return "MeshSplittingEngine", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component Mesh2PointTopologicalMapping

.. autofunction:: Mesh2PointTopologicalMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def Mesh2PointTopologicalMapping(self, **kwargs):
    """
    This class maps any mesh primitive (point, edge, triangle...) into a point using a relative position from the primitive



    """
    params = dict()
    return "Mesh2PointTopologicalMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component VTKExporter

.. autofunction:: VTKExporter

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def VTKExporter(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, XMLformat=None, position=None, edges=None, triangles=None, quads=None, tetras=None, hexas=None, pointsDataFields=None, cellsDataFields=None, exportEveryNumberOfSteps=None, exportAtBegin=None, exportAtEnd=None, overwrite=None, **kwargs):
    """
    Save State vectors from file at each timestep


    :param name: object name  Default value: VTKExporter

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: output VTK file name  Default value: 

    :param XMLformat: Set to true to use XML format  Default value: 1

    :param position: points position (will use points from topology or mechanical state if this is empty)  Default value: []

    :param edges: write edge topology  Default value: 1

    :param triangles: write triangle topology  Default value: 0

    :param quads: write quad topology  Default value: 0

    :param tetras: write tetra topology  Default value: 0

    :param hexas: write hexa topology  Default value: 0

    :param pointsDataFields: Data to visualize (on points)  Default value: []

    :param cellsDataFields: Data to visualize (on cells)  Default value: []

    :param exportEveryNumberOfSteps: export file only at specified number of steps (0=disable)  Default value: 0

    :param exportAtBegin: export file at the initialization  Default value: 0

    :param exportAtEnd: export file when the simulation is finished  Default value: 0

    :param overwrite: overwrite the file, otherwise create a new file at each export, with suffix in the filename  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, XMLformat=XMLformat, position=position, edges=edges, triangles=triangles, quads=quads, tetras=tetras, hexas=hexas, pointsDataFields=pointsDataFields, cellsDataFields=cellsDataFields, exportEveryNumberOfSteps=exportEveryNumberOfSteps, exportAtBegin=exportAtBegin, exportAtEnd=exportAtEnd, overwrite=overwrite)
    return "VTKExporter", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component HexahedronSetTopologyContainer

.. autofunction:: HexahedronSetTopologyContainer

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def HexahedronSetTopologyContainer(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, position=None, checkTopology=None, nbPoints=None, points=None, edges=None, checkConnexity=None, quads=None, createQuadArray=None, hexahedra=None, **kwargs):
    """
    Hexahedron set topology container


    :param name: object name  Default value: HexahedronSetTopologyContainer

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Filename of the mesh  Default value: 

    :param position: Initial position of points  Default value: []

    :param checkTopology: Parameter to activate internal topology checks (might slow down the simulation)  Default value: 0

    :param nbPoints: Number of points  Default value: 0

    :param points: List of point indices  Default value: []

    :param edges: List of edge indices  Default value: []

    :param checkConnexity: It true, will check the connexity of the mesh.  Default value: 0

    :param quads: List of quad indices  Default value: []

    :param createQuadArray: Force the creation of a set of quads associated with the hexahedra  Default value: 0

    :param hexahedra: List of hexahedron indices  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, position=position, checkTopology=checkTopology, nbPoints=nbPoints, points=points, edges=edges, checkConnexity=checkConnexity, quads=quads, createQuadArray=createQuadArray, hexahedra=hexahedra)
    return "HexahedronSetTopologyContainer", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SleepController

.. autofunction:: SleepController

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SleepController(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, minTimeSinceWakeUp=None, immobileThreshold=None, rotationThreshold=None, **kwargs):
    """
    A controller that puts node into sleep when the objects are not moving, and wake them up again when there are in collision with a moving object


    :param name: object name  Default value: SleepController

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param minTimeSinceWakeUp: Do not do anything before objects have been moving for this duration  Default value: 0.1

    :param immobileThreshold: Speed value under which we consider a particule to be immobile  Default value: 0.001

    :param rotationThreshold: If non null, this is the rotation speed value under which we consider a particule to be immobile  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, minTimeSinceWakeUp=minTimeSinceWakeUp, immobileThreshold=immobileThreshold, rotationThreshold=rotationThreshold)
    return "SleepController", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ConstantForceField

.. autofunction:: ConstantForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ConstantForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, indices=None, indexFromEnd=None, forces=None, force=None, totalForce=None, showArrowSize=None, showColor=None, **kwargs):
    """
    Constant forces applied to given degrees of freedom
Constant forces applied to given degrees of freedom
Constant forces applied to given degrees of freedom


    :param name: object name  Default value: ConstantForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param indices: indices where the forces are applied  Default value: []

    :param indexFromEnd: Concerned DOFs indices are numbered from the end of the MState DOFs vector. (default=false)  Default value: 0

    :param forces: applied forces at each point  Default value: []

    :param force: applied force to all points if forces attribute is not specified  Default value: [[0.0, 0.0, 0.0]]

    :param totalForce: total force for all points, will be distributed uniformly over points  Default value: [[0.0, 0.0, 0.0]]

    :param showArrowSize: Size of the drawn arrows (0->no arrows, sign->direction of drawing. (default=0)  Default value: 0.0

    :param showColor: Color for object display (default: [0.2,0.9,0.3,1.0])  Default value: [[0.20000000298023224, 0.8999999761581421, 0.30000001192092896, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, indices=indices, indexFromEnd=indexFromEnd, forces=forces, force=force, totalForce=totalForce, showArrowSize=showArrowSize, showColor=showColor)
    return "ConstantForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SimpleTesselatedTetraTopologicalMapping

.. autofunction:: SimpleTesselatedTetraTopologicalMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SimpleTesselatedTetraTopologicalMapping(self, **kwargs):
    """
    Special case of mapping where TetrahedronSetTopology is converted into a finer TetrahedronSetTopology



    """
    params = dict()
    return "SimpleTesselatedTetraTopologicalMapping", params
